MlDsa65KeyPair class final

An ML-DSA-65 key pair. seed is the 32-byte FIPS 204 seed that fully determines the pair; privateKey is the 4032-byte expanded key.

Constructors

MlDsa65KeyPair(Uint8List publicKey, Uint8List privateKey, Uint8List? seed)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
privateKey → Uint8List
final
publicKey → Uint8List
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seed → Uint8List?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited