MlKem768 class abstract final

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decaps(List<int> privateKey, List<int> ciphertext) → Uint8List
Recovers the shared secret from ciphertext with privateKey, which may be either the 2400-byte expanded key or the 64-byte seed.
encaps(List<int> publicKey) → Encapsulation
Encapsulates to publicKey, producing a ciphertext and shared secret.
keyPair({List<int>? seed}) → MlKem768KeyPair
Generates a key pair, from seed (64 bytes) when given.

Constants

algorithm → const String
ciphertextLength → const int
privateKeyLength → const int
publicKeyLength → const int
seedLength → const int
sharedSecretLength → const int