X25519 class abstract final

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

agree(List<int> privateKey, List<int> peerPublicKey) → Uint8List
The 32-byte shared secret between privateKey and peerPublicKey.
keyPair() → X25519KeyPair
Generates a fresh key pair.
publicKeyOf(List<int> privateKey) → Uint8List
The public key for a 32-byte privateKey.

Constants

algorithm → const String
keyLength → const int