OpenSSLException class final

An error reported by libcrypto, taken from ERR_get_error().

Implemented types

Constructors

OpenSSLException(String operation, List<int> codes, List<String> messages)
OpenSSLException.drain(String operation)
Drains the current thread's error queue into an OpenSSLException.
factory

Properties

codes → List<int>
Packed OpenSSL error codes (ERR_get_error()), oldest first. Empty when a call failed without queueing an error.
final
hashCode → int
The hash code for this object.
no setterinherited
messages → List<String>
Human readable strings for codes (ERR_error_string_n).
final
operation → String
What the caller was doing, e.g. EVP_PKEY_keygen.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited