Properties
hashCode
→ int
The hash code for this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited
Static Methods
keyPair ({List <int > ? seed })
→ MlDsa65KeyPair
Generates a key pair, from seed (32 bytes) when given.
sign (List <int > privateKey , List <int > message )
→ Uint8List
Signs message (pure ML-DSA, empty context string) with privateKey,
which may be the 4032-byte expanded key or the 32-byte seed. Signatures
are randomised ("hedged") as FIPS 204 recommends.
verify (List <int > publicKey , List <int > message , List <int > signature )
→ bool
Verifies signature over message with publicKey. Returns false on
a bad signature; throws OpenSSLException only for malformed inputs.