MlKem768KeyPair class final
An ML-KEM-768 key pair.
seed is the 64-byte FIPS 203 d || z seed; it fully determines the key
pair and is the recommended long-term storage form (at_chops stores it).
privateKey is the 2400-byte expanded decapsulation key.
Constructors
- MlKem768KeyPair(Uint8List publicKey, Uint8List privateKey, Uint8List? seed)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- privateKey → Uint8List
-
final
- publicKey → Uint8List
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seed → Uint8List?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited