X25519KeyPair class final
A raw X25519 key pair: 32-byte public and private keys.
Constructors
- X25519KeyPair(Uint8List publicKey, Uint8List privateKey)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- privateKey → Uint8List
-
final
- publicKey → Uint8List
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited